%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% Init.m
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Initialize simulation and start Simulink
% 
% Inputs:	-
%
% Outputs:	-
%	
% Calls:        Parameters
%               Load_vessel_data
%               Thruster_data
%               Exp_environ
%               Wind_spectrum
%               Init_Waves
%               MCSim
%
% Author:                   yvind Smogeli, Autumn 2002
% Revision:                 Vahid Hassani, Summer 2010
% Hybrid control:           Svenn Are Vrn and Astrid H. Brodtkorb 2014-2017
% Reachability analysis:    Astrid H. Brodtkorb fall 2018
% Autonomous docking:       Birte L. Steinsvik, spring 2019

%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 

clear all

disp(' ')
disp('***********************************************************')


Tsim = 500;

% Choose which vessel to simulate
% Vessel 1: Supply vessel, Lpp 80m, B 17.4m, T 5.6 m
% Vessel 2: CS3 Lpp1.971 m
% .....
Sim.vessno 				= 2; 			% 1: Supply , 2: CS3

% Choose which unberthing method to use for autodocking
Unb                     = 1;            % 1: Pid-unb, 2: unberthing force

% Antiwindup of the integrator in the PID controller
if Unb == 1
    aw = 2;             % With UNB1 the integrator is frozen for controller 2
end
if Unb == 2
    aw = [2,3];         % With UNB2 the integrator is frozen for controller 2 & 3
end

% Quay configuration
Quay.Pos = [3, 5,(90)*pi/180];     % Placement of quay in NE and angle for ship docking[m m rad]
Quay.Time = 100;                   % Desired time at quay [s]
Quay.Angle  = [0 90]*(pi/180);     % Angles the quay force works in [surge sway] (here the ship is docked in both sway and surge - as a ferry)

% Set simulation parameters
SimulationParameters;

% Read the vessel data
Par.Vessel = Load_vessel_data(Sim.vessno);

% Wind velocity at mean superstructure height (Par_Vessel.wind_arm_y)
z0 = 10*exp(-2/(5*sqrt(Par.Wind.kappa)));
Par.Wind.vel = Par.Wind.u10*5/2*sqrt(Par.Wind.kappa)*log(Par.Vessel.wind_arm_y/z0); 
Par.Wind.vel_2 = Par.Wind.u10_2*5/2*sqrt(Par.Wind.kappa)*log(Par.Vessel.wind_arm_y/z0); 

% Initialize wind gust components from spectrum 
Par.Wind = Wind_spectrum(Par.Wind, Par.Vessel.wind_arm_y);

% Load controller settings
ObserverParameters;
SensorModule;
ControlParameters;
Log;
ReferenceModel;



% Display initialization confirmation
yesno{1} = 'No';
yesno{2} = 'Yes';

disp(' ')
disp('***********************************************************')
disp('*                    MCSIM INITIALIZED                    *')
disp('***********************************************************')
disp(' ')
disp(['  Vessel: ', Par.Vessel.name])
disp(['  Using WF model: ', yesno{Sim.WF_model + 1}])
disp(['  Using LF model: ', yesno{Sim.LF_model + 1}])
disp(' ')
if Sim.LF_model == 1
	disp('  Load modules: ')
	disp(['    Wind:      ', yesno{Sim.Wind_load + 1}])
	disp(['    Current:   ', yesno{Sim.Current_load + 1}])
	disp(['    Wavedrift: ', yesno{Sim.Wavedrift_load + 1}])
	disp(' ')
	if sum(Sim.Ext_force) ~= 0
		disp(['    NB! External force: [', num2str(Sim.Ext_force), ']'])
		disp(['            Applied at: [', num2str(Sim.Ext_force_coord), ']'])
		disp(' ')
	end
end
% disp(['  Vessel Control: ', yesno{Sim.Control + 1}])
% if Sim.Control == 1
% 	disp(sprintf('    Controller      : %s ',Control.Types{Control.Type}))
% % 	disp(sprintf('    Feedback signal : %s ', Sim.Sensor.Feedback{Sim.Ideal_meas + 1}))
% % 	disp(sprintf('    Sensor models   : %s ', Sim.Sensor.Types{Sim.Sensors + 1}))
% 	disp(sprintf('    Observer        : %s ',Sim.VessObs.Types{Sim.Observer + 1}))
% end
% disp(' ')

disp(' ')
disp(['  Re-initialization of environment: ', yesno{2}])
if Par.Wind.gust == 1
	disp(sprintf('    Wind gust spectrum       : %s', Par.Wind.spectypes{Par.Wind.spectrum}))
end
disp(['    Varying wind direction   : ', yesno{Par.Wind.var_dir + 1}])
disp(['    Varying current magnitude: ', yesno{Par.Current.var_vel + 1}])
disp(['    Varying current direction: ', yesno{Par.Current.var_dir + 1}])
%if Sim.WF_model == 1 | (Sim.Thrusters.Enable == 1 & Sim.Thruster{1}.Wavecalc == 1) | Sim.Wavedrift_load == 1 % Display wave info only if it is used in simulation
%	disp(sprintf('    Wave spectrum            : %s', Par.Wave.spectypes{Par.Wave.spectrum}))
%	disp(['    Harmonic wave components : ', num2str(length(Par.Wave.Zeta_a))])
%	disp(['    Random wave frequencies  : ', yesno{Par.Wave.rand_freq + 1}])
%	disp(['    Random wave directions   : ', yesno{Par.Wave.rand_dir + 1}])
%	disp(['    Truncated wave components: ', num2str(Par.Wave.nfreq*Par.Wave.ndir - length(Par.Wave.Zeta_a))])
%end
disp(' ')
disp('***********************************************************')
disp(' ')

% Run simulation
sim('mcsim_2019_BLS');

return
% Plot
Plots;

